@@ -15,7 +15,7 @@ law.plot3d <- function(data,probfunc,tinf=-5,tsup=5) {
 
   g$z <- abs(apply(Mymat,FUN=Fhat,MARGIN=1)-probfunc(g$t))
   
-  print(wireframe(z ~ t + n, data = g,scales = list(arrows = FALSE),drape = TRUE, colorkey = TRUE,screen = list(z = -50, x = -70),zlab=expression(hat(l)[n]~'(t)'),main="Convergence in law?"))
+  print(wireframe(z ~ t + n, data = g,scales = list(arrows = FALSE),drape = TRUE, colorkey = TRUE,screen = list(z = -50, x = -70),zlab=list(expression(hat(l)[n]~'(t)=|'~hat(F)[n]~'(t)-'~F~'(t)|'),rot=90) ,main="Convergence in law?"))
   
 
 }
